@@ -236,6 +236,12 @@ impl Interaction {
                 .map(|uri| render_with_vars(uri.clone(), &vars, &fmtstring))
                 .collect::<Vec<_>>()
         });
+        if let Some(basic) = req.basic_auth.as_mut() {
+            basic.user = render_with_vars(basic.user.clone(), &vars, &fmtstring);
+            if let Some(password) = basic.password.as_ref() {
+                basic.password = Some(render_with_vars(password.clone(), &vars, &fmtstring))
+            }
+        }
 
         if let Some(aws) = req.aws_auth.as_mut() {
             aws.key = render_with_vars(aws.key.clone(), &vars, &fmtstring);
@@ -333,7 +339,7 @@ pub struct Param {
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct BasicAuth {
     pub user: String,
-    pub pass: Option<String>,
+    pub password: Option<String>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
