@@ -50,8 +50,9 @@ impl Sender for ReqwestSender {
             reqwest::Method::from_bytes(&method.clone().into_bytes()).unwrap(),
             &uri,
         );
+        rq_builder = rq_builder.header("User-Agent", "keyscope/1");
         if let Some(basic) = &request.basic_auth {
-            rq_builder = rq_builder.basic_auth(basic.user.clone(), basic.pass.clone());
+            rq_builder = rq_builder.basic_auth(basic.user.clone(), basic.password.clone());
         }
         if let Some(form) = &request.form {
             rq_builder = rq_builder.form(form);
